Skip to content

tohtml

Prints out an HTML table for the records from input or from files.

Synopsis

bash
recs tohtml [options] [files...]

Description

Prints out an HTML table for the records from input or from files.

Options

FlagDescription
--keys / -k / --key / --fields / -f <keys>Keys to print in the table. May be specified multiple times or comma separated. Defaults to all fields in the first record.
--noheaderDo not print the header row.
--rowattributes / --row <attributes>HTML attributes to put on the tr tags.
--cellattributes / --cell <attributes>HTML attributes to put on the td and th tags.

Examples

bash
recs tohtml
bash
recs tohtml --fields foo,bar --noheader

See Also

Released under the MIT License.