Skip to content

toprettyprint

Pretty print records, one key to a line, with a line of dashes separating records.

Synopsis

bash
recs toprettyprint [options] [files...]

Description

Pretty print records, one key to a line, with a line of dashes separating records. Especially useful for records with very large amounts of keys.

Options

FlagDescription
--1 / --oneOnly print the first record.
--n <n>Only print n records.
--keys / -k <keys>Only print out specified keys. May be keyspecs or keygroups.
--nonestedDo not nest the output of hashes, keep each value on one line.
--aligned `[rl

Examples

Pretty print records

bash
recs toprettyprint

Find all keys with 'time' in the name or value

bash
... | recs toprettyprint --one | grep time

See Also

Released under the MIT License.